summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-05 21:46:03 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-05 21:46:03 -0500
commit2fd0613a881b5c1b10e83c42c712fca4c171b715 (patch)
tree3416514188ee8fc3f7a6527d03d93042c14457d6
parent0fa8455ff4b4a0d8f19712ac5157831618d60b37 (diff)
downloadabakus-2fd0613a.tar.gz
abakus-2fd0613a.zip
Rename kde libraries to tde
-rw-r--r--bksys/kde.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/bksys/kde.py b/bksys/kde.py
index 1f435da..625e4ca 100644
--- a/bksys/kde.py
+++ b/bksys/kde.py
@@ -15,8 +15,8 @@ NORMAL ="\033[0m"
import os, re, types
from SCons.Script.SConscript import SConsEnvironment
# Returns the name of the shared object (i.e. libkdeui.so.4)
# referenced by a libtool archive (like libkdeui.la)
def getSOfromLA(lafile):
contents = open(lafile, 'r').read()
match = re.search("^dlname='([^']*)'$", contents, re.M)
@@ -119,8 +119,8 @@ def detect_kde(env):
else:
try:
tmplibdir = os.popen('kde-config --expandvars --install lib').read().strip()
- libkdeuiSO = tmplibdir+'/'+getSOfromLA(tmplibdir+'/libkdeui.la')
- m = re.search('(.*)/lib/libqt.*', os.popen('ldd ' + libkdeuiSO + ' | grep libqt').read().strip().split()[2])
+ libtdeuiSO = tmplibdir+'/'+getSOfromLA(tmplibdir+'/libtdeui.la')
+ m = re.search('(.*)/lib/libqt.*', os.popen('ldd ' + libtdeuiSO + ' | grep libqt').read().strip().split()[2])
except:
m=None
if m:
@@ -15,8 +15,8 @@ NORMAL ="\033[0m"
import os, re, types
from SCons.Script.SConscript import SConsEnvironment
-# Returns the name of the shared object (i.e. libkdeui.so.4)
-# referenced by a libtool archive (like libkdeui.la)
+# Returns the name of the shared object (i.e. libtdeui.so.4)
+# referenced by a libtool archive (like libtdeui.la)
def getSOfromLA(lafile):
contents = open(lafile, 'r').read()